Lua_FuncEntranceItem = class("Lua_FuncEntranceItem", Lua_ListCell);
function Lua_FuncEntranceItem:ctor(p)
    self:superCall("ctor", p, "FuncEntranceItem_skin");
end

function Lua_FuncEntranceItem:buildShowItem()
    self:superCall("buildShowItem");
    self.showBg:setEnable(false);
    self.showText_1:setEnable(false);
    self.showText_2:setEnable(false);
    self.showText_3:setEnable(false);
    self.maskImg:setEnable(false);
    self.lockIcon:setEnable(false);
    self.openText:setEnable(false);
end

function Lua_FuncEntranceItem:dispose()
    self:stopTimer();
    if self.redPoint ~= nil then
        self.redPoint:dispose();
        self.redPoint = nil;
    end
    if self.fightEff then
        self.fightEff:dispose();
        self.fightEff = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_FuncEntranceItem:setData(data)
    self.data = data;
    self.bg:setUrl(data.iconPath);

    self:stopTimer();
    if data.id == Lua_FuncPlayDefine.ARENA then -- 斗技场
        self:showArenaInfo();
    elseif data.id == Lua_FuncPlayDefine.CHAMPIONSHIP then -- 精英赛
        self:showChampionshipInfo();
    elseif data.id == Lua_FuncPlayDefine.EQUIP_COPY then -- 寂灭岛
        self:showEquipCopyInfo();
    else
        self.showText_1:setEnable(false);
        self.showText_2:setEnable(false);
    end

    self:checkIsOpened();
    self:setRedPoint(data.redPointId);
    self:checkIsFighting();
end

function Lua_FuncEntranceItem:startTimer()
    if self.bTimer ~= true then
        self.bTimer = true;
        Lua_CommonUtil.addTimer("Lua_FuncEntranceItem", 1, self, self.onTimer);
    end
end

function Lua_FuncEntranceItem:stopTimer()
    if self.bTimer == true then
        self.bTimer = false;
        Lua_CommonUtil.removeTimer(self, self.onTimer);
    end
end

function Lua_FuncEntranceItem:onTimer()
    if self.data.id == Lua_FuncPlayDefine.ARENA then
        local remainTime = self.remainTime - DataCenter.roleData.serverTime;
        if remainTime > 0 then
            self.showText_1:setEnable(true);
            self.showText_1.text = LanUtil.formateStr(303007, Lua_TimeTransform.transSeconds1(remainTime));            
        else
            self:stopTimer();
            self.showText_1:setEnable(false);
        end
    elseif self.data.id == Lua_FuncPlayDefine.CHAMPIONSHIP then
        local remainTime = self.remainTime - DataCenter.roleData.serverTime;
        if remainTime > 0 then
            self.showText_1:setEnable(true);
            self.showText_1.text = LanUtil.formateStr(570079, Lua_TimeTransform.transSeconds1(remainTime));            
        else
            self:stopTimer();
            self.showText_1:setEnable(false);
        end        
    else
        self:stopTimer();
    end
end

function Lua_FuncEntranceItem:showArenaInfo()
    self.remainTime = DataCenter.arenaData.settle_tick;
    if self.remainTime > 0 then
        self:startTimer();
        self:onTimer();
    else
        self:stopTimer();
    end
end

function Lua_FuncEntranceItem:showChampionshipInfo()
    self.remainTime = DataCenter.championshipData.startTick;
    if self.remainTime > 0 then
        self:startTimer();
        self:onTimer();
    else
        self:stopTimer();
    end
end

function Lua_FuncEntranceItem:showEquipCopyInfo()
    if self.data.id ~= Lua_FuncPlayDefine.EQUIP_COPY then
        return
    end

    local open_id = DataCenter.equipCopyUtil.first_artifact_id;
    if DataCenter.funcOpenData:isOpened(open_id) then
        local free_times = DataCenter.equipCopyData.free_times;
        local times_limit = DataCenter.equipCopyData.times_limit;
        if free_times == 0 then
            free_times = "<color=#FF0000>"..free_times.."</color>"
        end
        self.showText_1:setEnable(true);
        self.showText_1.text = LanUtil.formateStr(420102, tostring(free_times),tostring(times_limit));

        if DataCenter.equipCopyUtil.bOpeneMoreTeam then -- 组队开启
            self.showText_2:setEnable(true);
            local reward_times = DataCenter.equipCopyData.reward_times;
            if reward_times > 0 then--有奖励次数
                self.showText_2.text = LanUtil.formateStr(420103,tostring(reward_times),tostring(DataCenter.equipCopyUtil.more_reward_limit));
            else
                local help_times = DataCenter.equipCopyData.help_times;
                if help_times == 0 then
                    help_times = "<color=#FF0000>0</color>"
                end
                self.showText_2.text = LanUtil.formateStr(420104, tostring(help_times),tostring(DataCenter.equipCopyUtil.more_extra_limit));
            end
        else
            self.showText_2:setEnable(false);
        end
    else
        self.showText_1:setEnable(false);
        self.showText_2:setEnable(false);
    end
end

function Lua_FuncEntranceItem:checkIsOpened()
    local vo = DataCenter.funcPathUtil:getFuncPathVo(self.data.pathId)
    if vo == nil or vo.openState then
        self.maskImg:setEnable(false);
        self.lockIcon:setEnable(false);
        self.openText:setEnable(false);
    else
        self.maskImg:setEnable(true);
        self.lockIcon:setEnable(true);
        self.openText:setEnable(true);
        self.openText.text = vo.promptStr;
    end
end

function Lua_FuncEntranceItem:setRedPoint(id)
    if strIsNullOrEmpty(id) then
        if self.redPoint ~= nil then
            self.redPoint:changeRedPoint(nil);
        end
    else
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.content);
            self.redPoint:setLocation(110, 139, 0);
        end
        self.redPoint:changeRedPoint(id);
    end
end

function Lua_FuncEntranceItem:checkIsFighting()
    self.recordId = 0;
    if self.data ~= nil and self.data.templateList ~= nil then
        local list = self.data.templateList;
        for i = 1, #list do
            self.recordId = DataCenter.fightData:getRecordIdByTemplateId(list[i]);
            if self.recordId > 0 then
                break;
            end
        end
    end
    self:showFightEff(self.recordId > 0);
end

function Lua_FuncEntranceItem:showFightEff(value)
    if value then
        if self.fightEff == nil then
            self.fightEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_ty_zdbs_0101", "ui_ty_zdbs_0101", 273, 100)
        end
        self.fightEff:setEnable(true)
    else
        if self.fightEff then
            self.fightEff:setEnable(false)
        end
    end
end

function Lua_FuncEntranceItem:onPressClick()
    if self.data == nil then
        return;
    end
    if self.data.id == Lua_FuncPlayDefine.EQUIP_COPY and self.recordId == 0 then 
        if DataCenter.equipCopyData.team_id ~= 0 then-- 队伍中
            DataCenter.funcPathUtil:gotoFunction(1117);--组队
            return;
        else
            if DataCenter.equipCopyUtil.bOpeneMoreTeam then -- 组队开启
                DataCenter.funcPathUtil:gotoFunction(1117);--组队
                return;
            end
        end
    end

    DataCenter.funcPathUtil:gotoFunction(self.data.pathId);
end
